#!/bin/bash

echo "Start login script" >> $TMPDIR/login.log

desired=0
width=1280
height=1024

keyboards=`xinput | grep -v "XTEST" | grep "slave  keyboard" | sed -re 's/^.*\sid=([0-9]+)\s.*$/\1/'`
mouses=`xinput | grep -v "XTEST" | grep "slave  pointer" | sed -re 's/^.*\sid=([0-9]+)\s.*$/\1/'`
displays=$(xrandr | grep \ connected)
err_log=$(tac $TMPDIR/freerdp_error.log)
existing_modes=$(xrandr | grep -oP '\b\d+x\d+\b')

resolution_pattern='[.*]*Client\ from\ [^[:space:]]+\ is\ activated\ \(([0-9]+)x([0-9]+)@[0-9]+\).*'
display_settings_pattern='([a-zA-Z-]*[0-9]+)\ connected\ [^0-9]*([0-9]+x[0-9]+)\+([0-9]+)\+([0-9]+)'

# Удаление старых настроек мониторов
rm ~/.config/display_defaults.txt

# Получение разрешения клиента
while read line; do
    if [[ $line =~ $resolution_pattern ]]; then
        width=${BASH_REMATCH[1]}
        height=${BASH_REMATCH[2]}
        echo "Requested resolution $width $height" >> $TMPDIR/login.log
        break
    fi
done <<< "$err_log"

resolution=$(gtf $width $height 60 | grep 'Modeline' | cut -d '"' -f2 | cut -d '_' -f1)
modeline_output=$(gtf $width $height 60 | grep 'Modeline' | cut -d '"' -f3)

# Применение настроек мониторов в соостветствии с разрешением клиента
xrandr --newmode $resolution $modeline_output
echo "xrandr --newmode ${resolution} ${modeline_output}" >> $TMPDIR/login.log

xset dpms force standby

# Блокировка устройств ввода-вывода
for device in $mouses $keyboards
do
    xinput --set-prop $device "Device Enabled" $desired
done

# Сохранение настроек мониторов
while read line; do
    if [[ $line =~ $display_settings_pattern ]]; then
        device=$(echo $line | cut -d ' ' -f1)
        config=${BASH_REMATCH[2]}
        pos=${BASH_REMATCH[3]}x${BASH_REMATCH[4]}
        echo "$device $config $pos" >> ~/.config/display_defaults.txt
        xrandr --output $device --brightness $desired
        xrandr --addmode $device $resolution
        echo "xrandr --addmode ${device} ${resolution}" >> $TMPDIR/login.log
        xrandr -d :0 --output $device --mode $resolution --pos 0x0
        echo "xrandr -d :0 --output ${device} --mode ${resolution}" >> $TMPDIR/login.log
    fi
done <<< "$displays"

xrefresh

# Запуск сервиса блокировки устройств ввода-вывода
service_lock=$(systemctl --user status freerdp-locker.timer | grep "Active: inactive" | wc -l)

if [ $service_lock -eq 1 ]; then
    systemctl --user start freerdp-locker.timer
fi

echo "End login script" >> $TMPDIR/login.log
